#include "StdAfx.h"
#include "DataImpl.h"
#include "CharEncoding.h"
#include "Global.h"

CDataImpl::CDataImpl(void):m_psqlite3(NULL),m_pszErrmsg(NULL)
{
}

CDataImpl::~CDataImpl(void)
{
}

BOOL CDataImpl::Open()
{
	Close();
	CHAR szpath[MAX_PATH] = {0};
	_stprintf_s(szpath, _T("%ssms.db"), Global::g_szCurModuleDir );

	std::string strPath;
	if ( !CharEncoding::ASCII2UTF8(szpath,strPath))
	{
		return FALSE;
	}

	INT nResult = sqlite3_open(strPath.c_str(), &m_psqlite3);
	if ( nResult != SQLITE_OK )
		return FALSE;

	return TRUE;
}

void CDataImpl::Close()
{
	if ( m_psqlite3 )
		sqlite3_close(m_psqlite3);

	m_psqlite3 = NULL;
}

BOOL CDataImpl::ExecteSQL(IN LPCSTR lpSQL)
{
	if ( lpSQL == NULL || lpSQL[0] == '\0' )
	{
		//Global::WriteTextLog(_T("ExecteSQLִգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, lpSQL, NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("ExecteSQL:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}

INT CDataImpl::QueryContactsType(IN OUT std::vector<STContactsType> &vtContactsType)
{
	if ( m_psqlite3 == NULL )
		return -1;

	INT nRow = 0;
	INT nCol = 0;

	char** pazResult = NULL;
	int sqlite_error = sqlite3_get_table(m_psqlite3, "select Autoid, ContactsType from ContactsType", &pazResult, &nRow, &nCol, &m_pszErrmsg);
	if ( sqlite_error != SQLITE_OK)
	{
		//Global::WriteTextLog(_T("QueryContactsType:%s"), m_pszErrmsg);
		return -1;
	}

	for(int i = 1; i <= nRow; i++)
	{
		STContactsType tagObj;
#ifndef USE_UTF8
		tagObj.strAutoid = pazResult[i*nCol + 0];
		tagObj.strContactsType = pazResult[i*nCol + 1];
#else
		// Native for SQLite3ݣutf8ʽ;
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 0], tagObj.strAutoid);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 1], tagObj.strContactsType);
#endif

		vtContactsType.push_back(tagObj);
	}

	sqlite3_free_table(pazResult);

	return nRow;
}

INT CDataImpl::QueryContactsInfo(IN OUT std::vector<STContactsInfo> &vtContactsInfo)
{
	if ( m_psqlite3 == NULL )
		return -1;

	INT nRow = 0;
	INT nCol = 0;

	char** pazResult = NULL;
	int sqlite_error = sqlite3_get_table(m_psqlite3, "select Autoid, ContactsType, ContactsName,ContactsPhone, ContactsStatus from ContactsInfo", &pazResult, &nRow, &nCol, &m_pszErrmsg);
	if ( sqlite_error != SQLITE_OK)
	{
		//Global::WriteTextLog(_T("QueryContactsInfo:%s"), m_pszErrmsg);
		return -1;
	}

	for(int i = 1; i <= nRow; i++)
	{
		STContactsInfo tagObj;

#ifndef USE_UTF8
		tagObj.strAutoid = pazResult[i*nCol + 0];
		tagObj.strContactsType = pazResult[i*nCol + 1];
		tagObj.strContactsName = pazResult[i*nCol + 2];
		tagObj.strContactsPhone = pazResult[i*nCol + 3];
		tagObj.strContactsStatus = pazResult[i*nCol + 4];
#else
		// Native for SQLite3ݣutf8ʽ;
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 0], tagObj.strAutoid);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 1], tagObj.strContactsType);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 2], tagObj.strContactsName);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 3], tagObj.strContactsPhone);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 4], tagObj.strContactsStatus);
#endif

		vtContactsInfo.push_back(tagObj);
	}

	sqlite3_free_table(pazResult);

	return nRow;
}

INT CDataImpl::QueryTaskInfo(IN OUT std::vector<STTaskInfo> &vtTaskInfo)
{
	if ( m_psqlite3 == NULL )
		return -1;

	INT nRow = 0;
	INT nCol = 0;

	char** pazResult = NULL;
	int sqlite_error = sqlite3_get_table(m_psqlite3, "select Autoid,TirrgerTime, TaskPhone, TaskContent, ExecDate, TaskStatus, TirrgerCycle from TaskInfo", &pazResult, &nRow, &nCol, &m_pszErrmsg);
	if ( sqlite_error != SQLITE_OK)
	{
		//Global::WriteTextLog(_T("QueryTaskInfo:%s"), m_pszErrmsg);
		return -1;
	}

	for(int i = 1; i <= nRow; i++)
	{
		STTaskInfo tagObj;

#ifndef USE_UTF8
		tagObj.strAutoid = pazResult[i*nCol + 0];
		tagObj.strTirrgerTime = pazResult[i*nCol + 1];
		tagObj.strTaskPhone = pazResult[i*nCol + 2];
		tagObj.strTaskContent = pazResult[i*nCol + 3];
		tagObj.strExecDate = pazResult[i*nCol + 4];
		tagObj.strTaskStatus = pazResult[i*nCol + 5];
		tagObj.strTirrgerCycle = pazResult[i*nCol + 6];
#else
		// Native for SQLite3ݣutf8ʽ;
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 0], tagObj.strAutoid);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 1], tagObj.strTirrgerTime);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 2], tagObj.strTaskPhone);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 3], tagObj.strTaskContent);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 4], tagObj.strExecDate);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 5], tagObj.strTaskStatus);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 6], tagObj.strTirrgerCycle);
#endif

		vtTaskInfo.push_back(tagObj);
	}

	sqlite3_free_table(pazResult);

	return nRow;
}

INT CDataImpl::QuerySendRecord(IN OUT std::vector<STSendRecord> &vtSendRecord)
{
	if ( m_psqlite3 == NULL )
		return -1;

	INT nRow = 0;
	INT nCol = 0;

	char** pazResult = NULL;
	int sqlite_error = sqlite3_get_table(m_psqlite3, "select Autoid, SendId, SendType, SendDateTime,SendPhone,SendContent,SendStatus,SendLog from SendRecord", &pazResult, &nRow, &nCol, &m_pszErrmsg);
	if ( sqlite_error != SQLITE_OK)
	{
		//Global::WriteTextLog(_T("QueryContactsType:%s"), m_pszErrmsg);
		return -1;
	}

	for(int i = 1; i <= nRow; i++)
	{
		STSendRecord tagObj;

#ifndef USE_UTF8
		tagObj.strAutoid = pazResult[i*nCol + 0];
		tagObj.strSendId = pazResult[i*nCol + 1];
		tagObj.strSendType = pazResult[i*nCol + 2];
		tagObj.strSendDateTime = pazResult[i*nCol + 3];
		tagObj.strSendPhone = pazResult[i*nCol + 4];
		tagObj.strSendContent = pazResult[i*nCol + 5];
		tagObj.strSendResult = pazResult[i*nCol + 6];
		tagObj.strSendLog = pazResult[i*nCol + 7];
#else
		// Native for SQLite3ݣutf8ʽ;
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 0], tagObj.strAutoid);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 1], tagObj.strSendId);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 2], tagObj.strSendType);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 3], tagObj.strSendDateTime);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 4], tagObj.strSendPhone);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 5], tagObj.strSendContent);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 6], tagObj.strSendResult);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 7], tagObj.strSendLog);
#endif

		vtSendRecord.push_back(tagObj);
	}

	sqlite3_free_table(pazResult);

	return nRow;
}

INT CDataImpl::QuerySendRecord(IN LPCSTR lpSendId, IN OUT STSendRecord &SendRecord)
{
	if ( m_psqlite3 == NULL )
		return -1;

	INT nRow = 0;
	INT nCol = 0;

	char** pazResult = NULL;
	std::string strQuery = "select Autoid, SendType, SendId, SendDateTime,SendPhone,SendContent,SendStatus,SendLog from SendRecord where SendId = '";
	strQuery.append(lpSendId);
	strQuery.append("';");
	int sqlite_error = sqlite3_get_table(m_psqlite3, strQuery.c_str(), &pazResult, &nRow, &nCol, &m_pszErrmsg);
	if ( sqlite_error != SQLITE_OK)
	{
		//Global::WriteTextLog(_T("QueryContactsType:%s"), m_pszErrmsg);
		return -1;
	}

	for(int i = 1; i <= nRow; i++)
	{
		STSendRecord tagObj;

#ifndef USE_UTF8
		tagObj.strAutoid = pazResult[i*nCol + 0];
		tagObj.strSendType = pazResult[i*nCol + 1];
		tagObj.strSendId = pazResult[i*nCol + 2];
		tagObj.strSendDateTime = pazResult[i*nCol + 3];
		tagObj.strSendPhone = pazResult[i*nCol + 4];
		tagObj.strSendContent = pazResult[i*nCol + 5];
		tagObj.strSendResult = pazResult[i*nCol + 6];
		tagObj.strSendLog = pazResult[i*nCol + 7];
#else
		// Native for SQLite3ݣutf8ʽ;
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 0], SendRecord.strAutoid);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 1], SendRecord.strSendType);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 2], SendRecord.strSendId);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 3], SendRecord.strSendDateTime);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 4], SendRecord.strSendPhone);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 5], SendRecord.strSendContent);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 6], SendRecord.strSendResult);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 7], SendRecord.strSendLog);
#endif
	}

	sqlite3_free_table(pazResult);

	return nRow;
}

INT CDataImpl::QuerySendRecordByAutoid(IN LPCSTR lpAutoId, IN OUT STSendRecord &SendRecord)
{
	if ( m_psqlite3 == NULL )
		return -1;

	INT nRow = 0;
	INT nCol = 0;

	char** pazResult = NULL;
	std::string strQuery = "select Autoid, SendId, SendType, SendDateTime,SendPhone,SendContent,SendStatus,SendLog from SendRecord where Autoid = ";
	strQuery.append(lpAutoId);
	strQuery.append(";");
	int sqlite_error = sqlite3_get_table(m_psqlite3, strQuery.c_str(), &pazResult, &nRow, &nCol, &m_pszErrmsg);
	if ( sqlite_error != SQLITE_OK)
	{
		//Global::WriteTextLog(_T("QueryContactsType:%s"), m_pszErrmsg);
		return -1;
	}

	for(int i = 1; i <= nRow; i++)
	{
		STSendRecord tagObj;

#ifndef USE_UTF8
		tagObj.strAutoid = pazResult[i*nCol + 0];
		tagObj.strSendId = pazResult[i*nCol + 1];
		tagObj.strSendType = pazResult[i*nCol + 2];
		tagObj.strSendDateTime = pazResult[i*nCol + 3];
		tagObj.strSendPhone = pazResult[i*nCol + 4];
		tagObj.strSendContent = pazResult[i*nCol + 5];
		tagObj.strSendResult = pazResult[i*nCol + 6];
		tagObj.strSendLog = pazResult[i*nCol + 7];
#else
		// Native for SQLite3ݣutf8ʽ;
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 0], SendRecord.strAutoid);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 1], SendRecord.strSendId);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 2], SendRecord.strSendType);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 3], SendRecord.strSendDateTime);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 4], SendRecord.strSendPhone);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 5], SendRecord.strSendContent);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 6], SendRecord.strSendResult);
		CharEncoding::UTF82ASCII(pazResult[i*nCol + 7], SendRecord.strSendLog);
#endif
	}

	sqlite3_free_table(pazResult);

	return nRow;
}

BOOL CDataImpl::InsertContactsType(IN LPCSTR lpContactsType)
{
	if ( lpContactsType == NULL || lpContactsType[0] == '\0' )
	{
		//Global::WriteTextLog(_T("InsertContactsTypeգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "INSERT INTO ContactsType(ContactsType) VALUES ('";
#ifndef USE_UTF8
	strInsert.append(lpContactsType);
#else
	string str;
	CharEncoding::ASCII2UTF8(lpContactsType,str);
	strInsert.append(str);
#endif
	strInsert.append("');");

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("InsertContactsType:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}

BOOL CDataImpl::InsertContactsInfo(IN LPCSTR lpContactsType, IN LPCSTR lpContactsName, IN LPCSTR lpContactsPhone, IN LPCSTR lpContactsStatus)
{
	if ( lpContactsName == NULL || lpContactsName[0] == '\0' ||
		lpContactsPhone == NULL || lpContactsPhone[0] == '\0' ||
		lpContactsStatus == NULL || lpContactsStatus[0] == '\0' )
	{
		//Global::WriteTextLog(_T("InsertContactsInfoգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "INSERT INTO ContactsInfo(ContactsType,ContactsName,ContactsPhone,ContactsStatus) VALUES ('";
#ifndef USE_UTF8
	strInsert.append(lpContactsType);
	strInsert.append("','");
	strInsert.append(lpContactsName);
	strInsert.append("','");
	strInsert.append(lpContactsPhone);
	strInsert.append("','");
	strInsert.append(lpContactsStatus);
	strInsert.append("');");
#else
	string str;
	CharEncoding::ASCII2UTF8(lpContactsType,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpContactsName,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpContactsPhone,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpContactsStatus,str);
	strInsert.append(str);

	strInsert.append("');");
#endif

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("InsertContactsInfo:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}

BOOL CDataImpl::InsertTaskInfo(IN LPCSTR lpTirrgerCycle, IN LPCSTR lpTirrgerTime, IN LPCSTR lpTaskPhone, IN LPCSTR lpTaskContent, IN LPCSTR lpExecDate, IN LPCSTR lpTaskStatus)
{
	if ( lpTirrgerTime == NULL || lpTirrgerTime[0] == '\0' ||
		lpTirrgerCycle == NULL || lpTirrgerCycle[0] == '\0' ||
		lpTaskPhone == NULL || lpTaskPhone[0] == '\0'		||
		lpTaskContent == NULL || lpTaskContent[0] == '\0' ||
		lpTaskStatus == NULL || lpTaskStatus[0] == '\0' 
		)
	{
		//Global::WriteTextLog(_T("InsertTaskInfoգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "INSERT INTO TaskInfo(TirrgerCycle,TirrgerTime,TaskPhone,TaskContent,ExecDate,TaskStatus) VALUES (";
#ifndef USE_UTF8
	strInsert.append(lpTirrgerCycle);
	strInsert.append(",'");
	strInsert.append(lpTirrgerTime);
	strInsert.append("','");
	strInsert.append(lpTaskPhone);
	strInsert.append("','");
	strInsert.append(lpTaskContent);
	strInsert.append("','");
	strInsert.append(lpExecDate);
	strInsert.append("','");
	strInsert.append(lpTaskStatus);
	strInsert.append("');");
#else
	string str;
	CharEncoding::ASCII2UTF8(lpTirrgerCycle,str);
	strInsert.append(str);

	strInsert.append(",'");
	CharEncoding::ASCII2UTF8(lpTirrgerTime,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpTaskPhone,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpTaskContent,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpExecDate,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpTaskStatus,str);
	strInsert.append(str);

	strInsert.append("');");
#endif

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("InsertTaskInfo:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}

BOOL CDataImpl::InsertSendRecord(IN LPCSTR lpSendType, IN LPCSTR lpSendId, IN LPCSTR lpSendDateTime, IN LPCSTR lpSendPhone, IN LPCSTR lpSendContent, IN LPCSTR lpSendStatus, IN LPCSTR lpSendLog)
{
	if (lpSendDateTime == NULL || lpSendDateTime[0] == '\0' ||
		lpSendPhone == NULL || lpSendPhone[0] == '\0'		||
		lpSendContent == NULL || lpSendContent[0] == '\0' ||
		lpSendStatus == NULL || lpSendStatus[0] == '\0' 
		)
	{
		//Global::WriteTextLog(_T("InsertSendRecordգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "INSERT INTO SendRecord(SendType,SendId,SendDateTime,SendPhone,SendContent,SendStatus,SendLog) VALUES ('";
#ifndef USE_UTF8
	strInsert.append(lpSendType);
	strInsert.append("','");
	strInsert.append(lpSendId);
	strInsert.append("','");
	strInsert.append(lpSendDateTime);
	strInsert.append("','");
	strInsert.append(lpSendPhone);
	strInsert.append("','");
	strInsert.append(lpSendContent);
	strInsert.append("',");
	strInsert.append(lpSendStatus);
	strInsert.append(",'");
	strInsert.append(lpSendLog);
	strInsert.append("');");
#else
	string str;
	CharEncoding::ASCII2UTF8(lpSendType,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpSendId,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpSendDateTime,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpSendPhone,str);
	strInsert.append(str);

	strInsert.append("','");
	CharEncoding::ASCII2UTF8(lpSendContent,str);
	strInsert.append(str);

	strInsert.append("',");
	CharEncoding::ASCII2UTF8(lpSendStatus,str);
	strInsert.append(str);

	strInsert.append(",'");
	CharEncoding::ASCII2UTF8(lpSendLog,str);
	strInsert.append(str);

	strInsert.append("');");
#endif

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("InsertSendRecord:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}

BOOL CDataImpl::UpdateContactsType(IN LPCSTR lpAutoid, IN LPCSTR lpContactsType)
{
	if ( lpAutoid == NULL || lpAutoid[0] == '\0' ||
		lpContactsType == NULL || lpContactsType[0] == '\0')
	{
		//Global::WriteTextLog(_T("UpdateContactsTypeգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "UPDATE ContactsType SET ContactsType = '";
#ifndef USE_UTF8
	strInsert.append(lpContactsType);
	strInsert.append("' WHERE Autoid = ");
	strInsert.append(lpAutoid);
	strInsert.append(";");
#else
	string str;
	CharEncoding::ASCII2UTF8(lpContactsType,str);
	strInsert.append(str);

	strInsert.append("' WHERE Autoid = ");
	strInsert.append(lpAutoid);
	strInsert.append(";");
#endif

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("UpdateContactsType:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}

BOOL CDataImpl::UpdateContactsInfo(IN LPCSTR lpAutoid, IN LPCSTR lpContactsType, IN LPCSTR lpContactsName, IN LPCSTR lpContactsPhone, IN LPCSTR lpContactsStatus)
{
	if (lpAutoid == NULL || lpAutoid[0] == '\0' || 
		lpContactsName == NULL || lpContactsName[0] == '\0' ||
		lpContactsPhone == NULL || lpContactsPhone[0] == '\0' ||
		lpContactsStatus == NULL || lpContactsStatus[0] == '\0' )
	{
		//Global::WriteTextLog(_T("UpdateContactsInfoգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "UPDATE ContactsInfo SET ContactsType = '";
#ifndef USE_UTF8
	strInsert.append(lpContactsType);
	strInsert.append("', ContactsName = '");
	strInsert.append(lpContactsName);
	strInsert.append("', ContactsPhone = '");
	strInsert.append(lpContactsPhone);
	strInsert.append("', ContactsStatus = '");
	strInsert.append(lpContactsStatus);
	strInsert.append("' WHERE Autoid = ");
	strInsert.append(lpAutoid);
	strInsert.append(";");
#else
	string str;
	CharEncoding::ASCII2UTF8(lpContactsType,str);
	strInsert.append(str);

	strInsert.append("', ContactsName = '");
	CharEncoding::ASCII2UTF8(lpContactsName,str);
	strInsert.append(str);

	strInsert.append("', ContactsPhone = '");
	CharEncoding::ASCII2UTF8(lpContactsPhone,str);
	strInsert.append(str);

	strInsert.append("', ContactsStatus = '");
	CharEncoding::ASCII2UTF8(lpContactsStatus, str);
	strInsert.append(str);
	strInsert.append("' WHERE Autoid = ");
	strInsert.append(lpAutoid);
	strInsert.append(";");
#endif

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("UpdateContactsInfo:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}

BOOL CDataImpl::UpdateTaskInfo(IN LPCSTR lpTirrgerCycle, IN LPCSTR lpTirrgerTime, IN LPCSTR lpTaskPhone, IN LPCSTR lpTaskContent, IN LPCSTR lpExecDate)
{
	if (lpTirrgerCycle == NULL || lpTirrgerCycle[0] == '\0' ||
		lpTirrgerTime == NULL || lpTirrgerTime[0] == '\0' ||
		lpTaskPhone == NULL || lpTaskPhone[0] == '\0'		||
		lpTaskContent == NULL || lpTaskContent[0] == '\0' ||
		lpExecDate == NULL || lpExecDate[0] == '\0' 
		)
	{
		//Global::WriteTextLog(_T("UpdateTaskInfoգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "UPDATE TaskInfo SET ExecDate = '";
#ifndef USE_UTF8
	strInsert.append(lpExecDate);
	strInsert.append("' WHERE TirrgerTime = '");
	strInsert.append(lpTirrgerTime);
	strInsert.append("' and TirrgerCycle = ");
	strInsert.append(lpTirrgerCycle);
	strInsert.append(" and TaskPhone = '");
	strInsert.append(lpTaskPhone);
	strInsert.append("' and TaskContent = '");
	strInsert.append(lpTaskContent);
	strInsert.append("';");
#else
	string str;
	CharEncoding::ASCII2UTF8(lpExecDate,str);
	strInsert.append(str);

	strInsert.append("' where TirrgerTime = '");
	CharEncoding::ASCII2UTF8(lpTirrgerTime,str);
	strInsert.append(str);

	strInsert.append("' and TirrgerCycle = ");
	CharEncoding::ASCII2UTF8(lpTirrgerCycle,str);
	strInsert.append(str);

	strInsert.append(" and TaskPhone = '");
	CharEncoding::ASCII2UTF8(lpTaskPhone,str);
	strInsert.append(str);

	strInsert.append("' and TaskContent = '");
	CharEncoding::ASCII2UTF8(lpTaskContent,str);
	strInsert.append(str);

	strInsert.append("';");
#endif

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("UpdateTaskInfo:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}


BOOL CDataImpl::UpdateTaskInfo(IN LPCSTR lpAutoid, IN LPCSTR lpTirrgerCycle, IN LPCSTR lpTirrgerTime, IN LPCSTR lpTaskPhone, IN LPCSTR lpTaskContent, IN LPCSTR lpExecDate, IN LPCSTR lpTaskStatus)
{
	if (lpAutoid == NULL || lpAutoid[0] == '\0' || 
		lpTirrgerTime == NULL || lpTirrgerTime[0] == '\0' ||
		lpTirrgerCycle == NULL || lpTirrgerCycle[0] == '\0' ||
		lpTaskPhone == NULL || lpTaskPhone[0] == '\0'		||
		lpTaskContent == NULL || lpTaskContent[0] == '\0' ||
		lpTaskStatus == NULL || lpTaskStatus[0] == '\0' 
		)
	{
		//Global::WriteTextLog(_T("UpdateTaskInfoգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "UPDATE TaskInfo SET TirrgerTime = '";
#ifndef USE_UTF8
	strInsert.append(lpTirrgerTime);
	strInsert.append("', TirrgerCycle = ");
	strInsert.append(lpTirrgerCycle);
	strInsert.append(", TaskPhone = '");
	strInsert.append(lpTaskPhone);
	strInsert.append("', TaskContent = '");
	strInsert.append(lpTaskContent);
	strInsert.append("', ExecDate = '");
	strInsert.append(lpExecDate);
	strInsert.append("', TaskStatus = '");
	strInsert.append(lpTaskStatus);
	strInsert.append("' WHERE Autoid = ");
	strInsert.append(lpAutoid);
	strInsert.append(";");
#else
	string str;
	CharEncoding::ASCII2UTF8(lpTirrgerTime,str);
	strInsert.append(str);

	strInsert.append("', TirrgerCycle = ");
	CharEncoding::ASCII2UTF8(lpTirrgerCycle,str);
	strInsert.append(str);

	strInsert.append(", TaskPhone = '");
	CharEncoding::ASCII2UTF8(lpTaskPhone,str);
	strInsert.append(str);

	strInsert.append("', TaskContent = '");
	CharEncoding::ASCII2UTF8(lpTaskContent,str);
	strInsert.append(str);

	strInsert.append("', ExecDate = '");
	CharEncoding::ASCII2UTF8(lpExecDate,str);
	strInsert.append(str);

	strInsert.append("', TaskStatus = '");
	CharEncoding::ASCII2UTF8(lpTaskStatus, str);
	strInsert.append(str);

	strInsert.append("' WHERE Autoid = ");
	strInsert.append(lpAutoid);
	strInsert.append(";");
#endif

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("UpdateTaskInfo:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}


BOOL CDataImpl::UpdateSendRecord( IN LPCSTR lpSendId, IN LPCSTR lpSendStatus, IN LPCSTR lpSendLog)
{
	if (lpSendId == NULL || lpSendId[0] == '\0' || 
		lpSendStatus == NULL || lpSendStatus[0] == '\0' ||
		lpSendLog == NULL || lpSendLog[0] == '\0' 
		)
	{
		//Global::WriteTextLog(_T("UpdateSendRecordգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "UPDATE SendRecord SET SendStatus = ";
#ifndef USE_UTF8
	strInsert.append(lpSendStatus);
	strInsert.append(",SendLog = '");
	strInsert.append(lpSendLog);
	strInsert.append("' WHERE SendId = '");
	strInsert.append(lpSendId);
	strInsert.append("';");
#else
	string str;
	strInsert.append(lpSendStatus);

	strInsert.append(",SendLog = '");
	CharEncoding::ASCII2UTF8(lpSendLog,str);
	strInsert.append(str);

	strInsert.append("' WHERE SendId = '");
	strInsert.append(lpSendId);
	strInsert.append("';");
#endif

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("UpdateSendRecord:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}

BOOL CDataImpl::UpdateSendRecord(IN LPCSTR lpAutoid, IN LPCSTR lpSendId, IN LPCSTR lpSendDateTime, IN LPCSTR lpSendPhone, IN LPCSTR lpSendContent, IN LPCSTR lpSendStatus, IN LPCSTR lpSendLog)
{
	if (lpAutoid == NULL || lpAutoid[0] == '\0' || 
		lpSendDateTime == NULL || lpSendDateTime[0] == '\0' ||
		lpSendPhone == NULL || lpSendPhone[0] == '\0'		||
		lpSendContent == NULL || lpSendContent[0] == '\0' ||
		lpSendStatus == NULL || lpSendStatus[0] == '\0' 
		)
	{
		//Global::WriteTextLog(_T("UpdateSendRecordգ"));
		return FALSE;
	}

	if(m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "UPDATE SendRecord SET SendId = '";
#ifndef USE_UTF8
	strInsert.append(lpSendId);
	strInsert.append("',SendDateTime = '");
	strInsert.append(lpSendDateTime);
	strInsert.append("',SendPhone = '");
	strInsert.append(lpSendPhone);
	strInsert.append("',SendContent = '");
	strInsert.append(lpSendContent);
	strInsert.append("', SendStatus = ");
	strInsert.append(lpSendStatus);
	strInsert.append(",SendLog = '");
	strInsert.append(lpSendLog);
	strInsert.append("' WHERE Autoid = ");
	strInsert.append(lpAutoid);
	strInsert.append(";");
#else
	string str;
	CharEncoding::ASCII2UTF8(lpSendId,str);
	strInsert.append(str);

	strInsert.append("',SendDateTime = '");
	CharEncoding::ASCII2UTF8(lpSendDateTime,str);
	strInsert.append(str);

	strInsert.append("',SendPhone = '");
	CharEncoding::ASCII2UTF8(lpSendPhone,str);
	strInsert.append(str);

	strInsert.append("',SendContent = '");
	CharEncoding::ASCII2UTF8(lpSendContent,str);
	strInsert.append(str);

	strInsert.append("', SendStatus = ");
	strInsert.append(lpSendStatus);

	strInsert.append(",SendLog = '");
	CharEncoding::ASCII2UTF8(lpSendLog,str);
	strInsert.append(str);

	strInsert.append("' WHERE Autoid = ");
	strInsert.append(lpAutoid);
	strInsert.append(";");
#endif

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if(SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("UpdateSendRecord:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}

BOOL CDataImpl::ClearnTaskStatus(IN LPCSTR lpAutoid)
{
	if (lpAutoid == NULL || lpAutoid[0] == '\0' )
	{
		//Global::WriteTextLog(_T("ClearnTaskStatusգ"));
		return FALSE;
	}

	if (m_psqlite3 == NULL)
		return FALSE;

	std::string strInsert = "UPDATE TaskInfo SET ExecDate = ''";
	strInsert.append(" WHERE Autoid = ");
	strInsert.append(lpAutoid);
	strInsert.append(";");

	char* psqlite_error = NULL;
	int sqlite_error = sqlite3_exec(m_psqlite3, strInsert.c_str(), NULL, 0, &psqlite_error);
	if (SQLITE_OK != sqlite_error)
	{
		//Global::WriteTextLog(_T("ClearnTaskStatus:%s"), psqlite_error);
		return FALSE;
	}

	return TRUE;
}
